@@ -37,7 +37,7 @@ pub fn derive_arbitrary(input: DeriveInput) -> Result<TokenStream> {
         quote! {
             #type_parameters
             type Strategy = proptest::strategy::BoxedStrategy<Self>;
-            fn arbitrary_with(args: Self::Parameters) -> Self::Strategy {
+            fn arbitrary_with(args: <Self as proptest::arbitrary::Arbitrary>::Parameters) -> Self::Strategy {
                 #[allow(dead_code)]
                 fn _to_fn_ptr<T>(f: fn(&T) -> bool) -> fn(&T) -> bool {
                     f
@@ -166,7 +166,9 @@ impl AnyArgs {
             if self.setters.is_empty() {
                 quote!(proptest::arbitrary::any_with::<#ty>(#init))
             } else {
-                let setters = self.setters.into_iter().map(|(name, expr)| {
+                let mut setters: Vec<_> = self.setters.into_iter().collect();
+                setters.sort_by(|v0, v1| v0.0.cmp(&v1.0));
+                let setters = setters.into_iter().map(|(name, expr)| {
                     let member = Member::Named(to_valid_ident(&name).unwrap());
                     let expr = &expr.value;
                     quote!(_any_args.#member = #expr;)
