@@ -286,12 +286,14 @@ fn any_with_args_expr_private_constructor() {
     #[derive(Arbitrary, Debug)]
     #[arbitrary(args = sub_mod::TestArgsNoConstruct)]
     struct Inner {
+        #[allow(dead_code)]
         x: u32,
     }
 
     #[derive(Arbitrary, Debug)]
     struct TestInput {
         #[any(sub_mod::TestArgsNoConstruct::new())]
+        #[allow(dead_code)]
         inner: Inner,
     }
 }
@@ -1051,3 +1053,13 @@ fn manual_bound_variant() {
     }
     assert_arbitrary(any::<u16>().prop_map(|x| Outer::X(Inner(x))));
 }
+
+#[test]
+fn enum_with_variant_named_parameters() {
+    #[deny(warnings)]
+    #[derive(Arbitrary, Debug, PartialEq, Clone)]
+    enum MyEnum {
+        Parameters,
+        SomethingElse,
+    }
+}
